#  Module.mk - Makefile for the Psion conversion utilities
#  Copyright (c) 1999  Frodo Looijaard <frodol@dds.nl>
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

# Note that MODULE_DIR (the directory in which this file resides) is a
# 'simply expanded variable'. That means that its value is substituted
# verbatim in the rules, until it is redefined. 
MODULE_DIR := lib

# Shared library versions
LIBVER_MAJOR=0
LIBVER=$(LIBVER_MAJOR).0.0
LIBNAME=libpsiconv

LIB_DIR := $(MODULE_DIR)

# Regrettably, even 'simply expanded variables' will not put their currently
# defined value verbatim into the command-list of rules...
# Regrettably, even 'simply expanded variables' will not put their currently
# defined value verbatim into the command-list of rules...
LIBTARGETS :=
ifeq ($(STATIC),1)
LIBTARGETS += $(MODULE_DIR)/$(LIBNAME).a
endif
ifeq ($(SHARED),1)
LIBTARGETS += $(MODULE_DIR)/$(LIBNAME).so.$(LIBVER)
LIBTARGETS_EXTRA := $(MODULE_DIR)/$(LIBNAME).so \
                    $(MODULE_DIR)/$(LIBNAME).so.$(LIBVER_MAJOR)
endif

LIBSOURCES := $(MODULE_DIR)/list.c $(MODULE_DIR)/data.c \
              $(MODULE_DIR)/checkuid.c \
              $(MODULE_DIR)/parse_aux.c $(MODULE_DIR)/parse_simple.c \
              $(MODULE_DIR)/parse_layout.c $(MODULE_DIR)/parse_common.c \
              $(MODULE_DIR)/parse_page.c $(MODULE_DIR)/parse_texted.c \
              $(MODULE_DIR)/parse_word.c $(MODULE_DIR)/parse_driver.c \
              $(MODULE_DIR)/gen_html.c $(MODULE_DIR)/gen_html4.c \
              $(MODULE_DIR)/gen_txt.c

LIBINCLUDES :=  $(MODULE_DIR)/list.h $(MODULE_DIR)/general.h \
                $(MODULE_DIR)/data.h \
                $(MODULE_DIR)/parse_routines.h $(MODULE_DIR)/parse.h \
                $(MODULE_DIR)/gen.h

# Include all dependency files
ifeq ($(STATIC),1)
INCLUDEFILES += $(LIBSOURCES:.c=.d)
endif
ifeq ($(SHARED),1)
INCLUDEFILES += $(LIBSOURCES:.c=.sd)
endif

$(MODULE_DIR)/$(LIBNAME).a: $(LIBSOURCES:.c=.o)
	$(AR) rcv $@ $^ 

$(MODULE_DIR)/$(LIBNAME).so: 
	ln -sfn $(LIBNAME).so.$(LIBVER_MAJOR) $(LIB_DIR)/$(LIBNAME).so

$(MODULE_DIR)/$(LIBNAME).so.$(LIBVER_MAJOR):
	ln -sfn $(LIBNAME).so.$(LIBVER) $(LIB_DIR)/$(LIBNAME).so.$(LIBVER_MAJOR)

$(MODULE_DIR)/$(LIBNAME).so.$(LIBVER): $(LIBSOURCES:.c=.so)
	$(CC) -shared -Wl,-soname,$(LIBNAME).so.$(LIBVER) -o $@ $^ -lc
	
all-lib: $(LIBTARGETS) $(LIBTARGETS_EXTRA)
all :: all-lib

install-lib: all-lib
	$(MKDIR) $(LIBDIR) $(INCLUDEDIR)
	$(INSTALL) -o root -g root -m 644 $(LIBTARGETS) $(LIBDIR)
	for file in $(LIBINCLUDES) ; do \
	  cat $$file | sed 's@#include "(\S*.h)"@#include <psiconv/\1>@' > $$file.install; \
	  $(INSTALL) -o root -g root -m 644 $$file.install $(INCLUDEDIR)/`basename $$file`; \
	  $(RM) $$file.install ; \
	done
ifeq ($(SHARED),1)
	ln -sfn $(LIBNAME).so.$(LIBVER_MAJOR) $(LIBDIR)/$(LIBNAME).so
	ln -sfn $(LIBNAME).so.$(LIBVER) $(LIBDIR)/$(LIBNAME).so.$(LIBVER_MAJOR)
endif

install :: install-lib

clean-lib:
	$(RM) $(LIBSOURCES:.c=.d) $(LIBSOURCES:.c=.o) $(LIBSOURCES:.c=.so) \
              $(LIBSOURCES:.c=.sd) $(LIBINCLUDES:.h=.h.install) \
              $(LIBTARGETS) $(LIBTARGETS_EXTRA)
clean :: clean-lib

.PHONY: clean-lib all-lib install-lib
